@@ -72,7 +72,7 @@ def D(elemento,color = "black"):#Por default se imprime en rojo, para indicar qu
     IPython.display.display(IPython.display.Latex("\\textcolor{"+color+"}{"+texto+"}"))
     print(Documento)
     print(Documento + " /n"+str(texto))
-    Documento = Documento + " /n"+str(texto)
+    Documento = str(Documento) + " /n"+str(texto)
 
   if Tipo == "Componente":#Si hemos identificado el elemento ingresado como un componente, entonces lo imprimimos en rojo
 
@@ -92,7 +92,7 @@ def D(elemento,color = "black"):#Por default se imprime en rojo, para indicar qu
     IPython.display.display(IPython.display.Latex("\\textcolor{"+color+"}{"+texto+"}"))
     print(Documento)
     print(Documento + " /n"+str(texto))
-    Documento = Documento + " /n"+str(texto)
+    Documento = str(Documento) + " /n"+str(texto)
 
 #def E(expr,color = "red"):
 #  DataRealSymbolList = []#Guarda en formato symbolo todos los Datos
